\name{BayesFdr-functions}
\alias{BayesFdr}
\alias{snpEM}
\alias{calBayesFdr}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Functions to control Fdr in single-study analysis 
}
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
\code{BayesFdr} is a (Bayesian) Fdr controlling method used in single-study analysis. \code{snpEM} is a built-in function to infer the parameters in the one-dimensional Gaussian Mixture Model. \code{calBayesFdr} is a built-in function to calculate the Fdr after given parameters in the Gaussian Mixture Model.
}
\usage{
BayesFdr(z, q, K = 2, beta0 = length(z)/5)

snpEM(z, K=2, maxIter=1000, tol=1e-4, beta0=length(z)/5, info=TRUE)

calBayesFdr(t, Pi1, sigma2)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{z}{
%%     ~~Describe \code{z} here~~
  The vector containing z values of all SNPs.
}
  \item{q}{
%%     ~~Describe \code{q} here~~
  The Fdr controlling level. 
}
  \item{K}{
%%     ~~Describe \code{K} here~~
 The components number of the z values in associated SNPs.
}
  \item{beta0}{
%%     ~~Describe \code{beta0} here~~
 The penalty term for pi0. We add Dirichlet(beta0, 0) prior to proportions (pi0, Pi1).
}
  \item{maxIter}{
 The maximum number of iterations.
}
  \item{tol}{
 The relative error tolerance.
}
  \item{info}{
 A logical number indicating whether the results should be printed out.
}
  \item{t}{
 The critical value for z-values.
}
  \item{Pi1}{
 The vector including the proportion of each associated component.
}
  \item{sigma2}{
 The vector including the variance of standardized effect sizes in each associated component.
}
}
\details{
%%  ~~ If necessary, more details than the description above ~~
These functions are the implementation of controlling the Fdr in single-study analysis. Here we assume the z-values follow the (K+1)-component Gaussian Mixture Model:

Z~pi_0 N(0,1)+sum_{(k=1)}^K pi_{1k} N(0, 1+sigma2_{k}).

\code{snpEM} is a built-in function to infer the parameters in the one-dimensional Gaussian Mixture Model using EM-algorithm. 

\code{calBayesFdr} is a built-in function to calculate the Fdr after given parameters in the Gaussian Mixture Model.

\code{BayesFdr} is a Fdr controlling method used in single-study analysis. \code{snpEM} and \code{calBayesFdr} are called in \code{BayesFdr}.
}
\value{
%%  ~Describe the value returned
%%  If it is a LIST, use
%%  \item{comp1 }{Description of 'comp1'}
%%  \item{comp2 }{Description of 'comp2'}
%% ...
\code{BayesFdr} returns the critical value and the indexes of the rejected null hypotheses. The returned value is a LIST:
\item{thld}{
The determined critical value in terms of z-value.
}
\item{idx}{
The indexes of the rejected null hypotheses.
}

\code{snpEM} returns the inferred parameters and the iteration status. The returened value is a LIST:
\item{pi0}{
The infered proportion of true null hypotheses.
}
\item{Pi1}{
The vector including the inferred proportion of each associated component. 
}
\item{sigma2}{
The vector including the inferred variance of standardized effect sizes in each associated component.
}
\item{h0}{
The vector including the probability of being true null hypothesis for each SNP.
}
\item{h}{
A K-vector list. Each vector includes the probability of being component k (1<=k<=K) for each SNP.
}
\item{iter}{
The iteration number.
}
\item{Qval}{
The expected negative log-likelihood.
}
\code{calBayesFdr} returns the Fdr value for a given threshold t.
}
\references{
%% ~put references to the literature/web site here ~
Jiang, W. and Yu, W.  \emph{Controlling the joint local false discovery rate is more powerful than meta-analysis methods in joint analysis of summary statistics from multiple genome-wide association studies}. Submitted.
}
\author{
%%  ~~who you are~~
Wei Jiang and Weichuan Yu

Maintainer: Wei Jiang <wjiangaa@connect.ust.hk>
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
\code{\link[Jlfdr:Jlfdr]{Jlfdr}}, 
\code{\link[Jlfdr:FdrControl2]{FdrControl2}}
}
\examples{
q<-5e-5                   #Fdr Threshold

##Load data
data('SmryStats1')        #Example of summary statistics in 1st study

z1<-SmryStats1$Z          #Z values in 1st study

####Bayes Fdr Control###
FdrResult<-BayesFdr(z1, q=q, K=2, beta0=length(z1)/5)
rejectedIdx<-FdrResult$idx #The indexes of the rejected null hypotheses

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
