\name{Jlfdr-functions}
\alias{FdrControl2}
\alias{snpEM2}
\alias{calJlfdr2}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Functions to control Fdr in joint analysis of multiple GWASs via Jlfdr-based method
}
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
\code{FdrControl2} is a novel summary-statistics-based joint analysis method to infer which SNPs have associations with traits. The method is based on controlling the joint local false discovery rate (Jlfdr). \code{snpEM2} is a built-in function to infer the parameters in the Gaussian Mixture Model. \code{calJlfdr2} is a built-in function to calculate the Jlfdr of each SNP after given parameters in the Gaussian Mixture Model.
}
\usage{
FdrControl2(z1, z2, K = 2, q = 0.05, beta0 = length(z1)/5, plot = T,
 output = T, dir = "output")

snpEM2(z1, z2, K=2, maxIter=1000, tol=1e-4, beta0=length(z1)/5, info=TRUE)

calJlfdr2(z1, z2, Pi1, Sigma)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{z1}{
%%     ~~Describe \code{z1} here~~
The vector containing z values of all SNPs from Study 1.
}
  \item{z2}{
%%     ~~Describe \code{z2} here~~
The vector containing z values of all SNPs from Study 2.
}
  \item{K}{
%%     ~~Describe \code{K} here~~
The components number of the z values in associated SNPs.
}
  \item{q}{
%%     ~~Describe \code{q} here~~
The Fdr controlling level. 
}
  \item{beta0}{
%%     ~~Describe \code{beta0} here~~
The penalty term for pi0. We add Dirichlet(beta0, 0) prior to proportions (pi0, Pi1).
}
  \item{plot}{
%%     ~~Describe \code{plot} here~~
A logical number indicating whether to plot the discovered associations in the z-value plane.
}
  \item{output, info}{
%%     ~~Describe \code{output} here~~
A logical number indicating whether the results should be printed out.
}
  \item{dir}{
%%     ~~Describe \code{dir} here~~
The directory to save the results when \code{output=T}
}
  \item{maxIter}{
The maximum number of iterations.
}
  \item{tol}{
The relative error tolerance.
}
  \item{Pi1}{
The vector including the proportion of each associated component.
}
  \item{Sigma}{
A K-objects list. Each object is the covariance matrix of standarized effect size vector in the corresponding associated component.
} 
}
\details{
%%  ~~ If necessary, more details than the description above ~~
These functions are the implementation of Jlfdr-based method to control the Fdr in joint analysis of multiple GWASs. Here we assume the z-value vector follow the (K+1)-component Gaussian Mixture Model:

Z~pi_0 N(0,I)+sum_{(k=1)}^K pi_{1k} N(0, I+Sigma_{k}).

\code{snpEM2} is a built-in function to infer the parameters in the Gaussian Mixture Model using EM-algorithm. 

\code{calJlfdr2} is a built-in function to calculate the Jlfdr of each SNP after given parameters in the Gaussian Mixture Model.

\code{FdrControl2} is based on controlling the joint local false discovery rate (Jlfdr) in the joint analysis of multiple GWASs. \code{snpEM2} and \code{calJlfdr2} are called in \code{FdrControl2}.
}
\value{
%%  ~Describe the value returned
%%  If it is a LIST, use
%%  \item{comp1 }{Description of 'comp1'}
%%  \item{comp2 }{Description of 'comp2'}
%% ...
\code{FdrControl2} returns the following LIST:
\item{Pi1}{
The vector including the inferred proportion of each associated component. 
}
\item{Sigma}{
A K-objects list. Each object is the inferred covariance matrix of standarized effect size vector in the corresponding associated component.
}
\item{rejected}{
The indexes of the rejected null hypotheses.
}
\item{JlfdrThld}{
The determined threshold for Jlfdr.
}
\item{Jlfdr}{
The vector including the calculated Jlfdr value for each SNP.
}

\code{snpEM2} returns the infered parameters and the iteration status. The returened value is a LIST:
\item{pi0}{
The infered proportion of true null hypotheses.
}
\item{Pi1}{
The vector including the infered proportion of each associated component. 
}
\item{Sigma}{
A K-objects list. Each object is the inferred covariance matrix of standarized effect size vector in the corresponding associated component.
}
\item{h0}{
The vector including the probability of being true null hypothesis for each SNP.
}
\item{h}{
A K-vector list. Each vector includes the probability of being component k (1<=k<=K) for each SNP.
}
\item{iter}{
The iteration number.
}
\item{Qval}{
The expected negative log-likelihood.
}

\code{calJlfdr2} returns the calculated Jlfdr value for each SNP.
}
\references{
Jiang, W. and Yu, W.  \emph{Controlling the joint local false discovery rate is more powerful than meta-analysis methods in joint analysis of summary statistics from multiple genome-wide association studies}. Submitted.
}
\author{
Wei Jiang and Weichuan Yu

Maintainer: Wei Jiang <wjiangaa@connect.ust.hk>
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
\code{\link[Jlfdr:Jlfdr]{Jlfdr}}, 
\code{\link[Jlfdr:BayesFdr]{BayesFdr}}
}
\examples{
q<-5e-5                   #Fdr Threshold

##Load data
data('SmryStats1')        #Example of summary statistics in 1st study
data('SmryStats2')        #Example of summary statistics in 2nd study

z1<-SmryStats1$Z          #Z values in 1st study
z2<-SmryStats1$Z          #Z values in 2nd study

######  Jlfdr-based method  ######
FdrResult<-FdrControl2(z1,z2, K=2, beta0=length(z1)/5, q=q,dir='.')
rejectedIdx<-FdrResult$rejected #The indexes of the rejected null hypotheses

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
