\name{Jlfdr-package}
\alias{Jlfdr-package}
\alias{Jlfdr}
\alias{SmryStats1}
\alias{Param1}
\alias{SmryStats2}
\alias{Param2}
\docType{package}
\title{
\packageTitle{Jlfdr}
}
\description{
\packageDescription{Jlfdr}
}
\details{
\tabular{ll}{
Package: \tab Jlfdr\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2016-05-26\cr
License: \tab GPL-3\cr
}

In genome-wide association studies (GWASs) of common diseases/traits, we often analyze multiple GWASs with the same phenotype together to discover associated genetic variants with higher power. Since it is diffcult to access data with detailed individual measurements, summary-statistics-based meta-analysis methods have
become popular to jointly analyze data sets from multiple GWASs.

Here we implement a novel summary-statistics-based joint analysis method based on controlling the joint local false discovery rate (Jlfdr). This method is the most powerful summary-statistics-based joint analysis method when controlling the false discovery rate (Fdr) at a certain level. Details about the method can be seen in our reference paper below.

The principal component of Jlfdr package is \code{FdrControl2}. Also we implement a Fdr controlling method \code{BayesFdr} for single-study analysis.

1. To jointly analyze summary statistics from multiple GWASs, we need to obtain the z-values of each genotyped SNPs in all studies. We have put example summary statistics of two studies (SmryStats1 and SmryStats2) in our package. You can use \code{data(SmryStats1)} and \code{data(SmryStats2)} to load the example data. You can also obtain the ground-truth parameters (allele frequencies, odds ratios) of the example data using \code{data(Param1)} and \code{data(Param2)}

2. You can use \code{FdrControl2} to jointly analyze summary statistics from two stuides.  

\code{FdrControl2(z1, z2, K=2, q=0.05, beta0=length(z1)/5, plot=T, output=T, dir='output')}

Details about the function can be seen using \code{\link[Jlfdr:FdrControl2]{help(FdrControl2)}}.

3. To analyze summary statistics from single study with controlling Fdr, \code{BayesFdr} can be used.  

\code{BayesFdr(z, q, K = 2, beta0 = length(z)/5)}

Details about the function can be seen using \code{\link[Jlfdr:BayesFdr]{help(BayesFdr)}}
}

\author{
Wei Jiang and Weichuan Yu

Maintainer: Wei Jiang <wjiangaa@connect.ust.hk>
}
\keyword{package}
\references{
Jiang, W. and Yu, W.  \emph{Controlling the joint local false discovery rate is more powerful than meta-analysis methods in joint analysis of summary statistics from multiple genome-wide association studies}. Submitted.
}
\seealso{
\code{\link[Jlfdr:FdrControl2]{FdrControl2}}, 
\code{\link[Jlfdr:BayesFdr]{BayesFdr}}
}
\examples{
q<-5e-5                   #Fdr Threshold

##Load data
data('SmryStats1')        #Example of summary statistics in 1st study
data('SmryStats2')        #Example of summary statistics in 2nd study

z1<-SmryStats1$Z          #Z values in 1st study
z2<-SmryStats1$Z          #Z values in 2nd study

######  Jlfdr-based method  ######
FdrResult<-FdrControl2(z1,z2, K=2, beta0=length(z1)/5, q=q,dir='.')
rejectedIdx<-FdrResult$rejected  #The indexes of the rejected null hypotheses

}
